@@ -30,7 +30,6 @@
 ## @subsubheading Examples
 ## Open device 0, and poll and display read messages
 ## @example
-## @code {
 ## dev = mididevice(0);
 ## while true
 ##    mx = midireceive(dev);
@@ -39,13 +38,12 @@
 ##      mx
 ##    endif
 ## endwhile
-## }
 ## @end example
 ##
 ## @seealso{mididevice, midisend}
 ## @end deftypefn
 
-function msg = midireceive (dev, maxmsg)
+function msg = midireceive (dev, maxmsg=0)
   if nargin < 1 || !isobject(dev) || !strcmp(typeinfo(dev), "octave_midi")
     error ("Expected midi device");
   endif
@@ -55,7 +53,6 @@ function msg = midireceive (dev, maxmsg)
   endif
 
   msg = midimsg (0);
-
   [ts, data] = __midirecv__(dev);
   while !isempty(data)
     msg = [ msg midimsg.createMessage(data, ts) ];
